#ifndef BOOST_SIMD_INCLUDE_FUNCTIONS_SIMD_TWO_PROD_HPP_INCLUDED
#define BOOST_SIMD_INCLUDE_FUNCTIONS_SIMD_TWO_PROD_HPP_INCLUDED

#include <boost/simd/arithmetic/include/functions/simd/two_prod.hpp>

#endif
